Class: Google::Maps::Isochrones::V1::GenerateIsochroneRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/maps/isochrones/v1/isochrones_service.rb

Overview

A request to generate a single isochrone.

Defined Under Namespace

Modules: PolygonFidelity, RoutingPreference, TravelDirection, TravelMode

Instance Attribute Summary collapse

Instance Attribute Details

#enable_smoothing::Boolean

Returns Optional. Specifies whether to smooth the edges of the resulting isochrone polygons.

Returns:

  • (::Boolean)

    Optional. Specifies whether to smooth the edges of the resulting isochrone polygons.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 58

class GenerateIsochroneRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the mode of transportation for isochrone calculation.
  module TravelMode
    # No travel mode specified.
    TRAVEL_MODE_UNSPECIFIED = 0

    # Travel by passenger car.
    DRIVE = 1

    # Travel by bicycle.
    BICYCLE = 2

    # Travel by walking.
    WALK = 3
  end

  # Specifies the direction of travel for the isochrone calculation.
  module TravelDirection
    # No travel direction specified.
    TRAVEL_DIRECTION_UNSPECIFIED = 0

    # Calculates the area reachable *from* the origin point.
    # Example: "Where can I deliver to from my warehouse in 30 minutes?"
    FROM = 1

    # Calculates the area from which you can travel *to* the origin point.
    # Example: "Where can my employees commute from to reach the office in 30
    # minutes?"
    TO = 2
  end

  # Determines how traffic conditions are incorporated into the calculation.
  module RoutingPreference
    # No routing preference specified. The server will use its default,
    # which is TRAFFIC_UNAWARE.
    ROUTING_PREFERENCE_UNSPECIFIED = 0

    # The calculation will not take traffic conditions into consideration.
    # The isochrone will be based on the road network and static travel times.
    # This is suitable for planning purposes where traffic is not a factor.
    TRAFFIC_UNAWARE = 1

    # The calculation will factor in live traffic conditions.
    TRAFFIC_AWARE = 2
  end

  # Controls the level of detail in the isochrone polygon.
  module PolygonFidelity
    # No polygon fidelity specified. The server will use its default, which
    # is based on the travel duration.
    POLYGON_FIDELITY_UNSPECIFIED = 0

    # Low precision. Good for covering large areas with fewer vertices.
    LOW = 1

    # Medium precision. A balance between detail and artifact size.
    MEDIUM = 2

    # High precision. High fidelity edges, but may produce holes in the polygon
    # where the road network density is low.
    HIGH = 3
  end
end

#location::Google::Type::LatLng

Returns The origin as a latitude/longitude coordinate.

Note: The following fields are mutually exclusive: location, place. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Type::LatLng)

    The origin as a latitude/longitude coordinate.

    Note: The following fields are mutually exclusive: location, place. If a field in that set is populated, all other fields in the set will automatically be cleared.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 58

class GenerateIsochroneRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the mode of transportation for isochrone calculation.
  module TravelMode
    # No travel mode specified.
    TRAVEL_MODE_UNSPECIFIED = 0

    # Travel by passenger car.
    DRIVE = 1

    # Travel by bicycle.
    BICYCLE = 2

    # Travel by walking.
    WALK = 3
  end

  # Specifies the direction of travel for the isochrone calculation.
  module TravelDirection
    # No travel direction specified.
    TRAVEL_DIRECTION_UNSPECIFIED = 0

    # Calculates the area reachable *from* the origin point.
    # Example: "Where can I deliver to from my warehouse in 30 minutes?"
    FROM = 1

    # Calculates the area from which you can travel *to* the origin point.
    # Example: "Where can my employees commute from to reach the office in 30
    # minutes?"
    TO = 2
  end

  # Determines how traffic conditions are incorporated into the calculation.
  module RoutingPreference
    # No routing preference specified. The server will use its default,
    # which is TRAFFIC_UNAWARE.
    ROUTING_PREFERENCE_UNSPECIFIED = 0

    # The calculation will not take traffic conditions into consideration.
    # The isochrone will be based on the road network and static travel times.
    # This is suitable for planning purposes where traffic is not a factor.
    TRAFFIC_UNAWARE = 1

    # The calculation will factor in live traffic conditions.
    TRAFFIC_AWARE = 2
  end

  # Controls the level of detail in the isochrone polygon.
  module PolygonFidelity
    # No polygon fidelity specified. The server will use its default, which
    # is based on the travel duration.
    POLYGON_FIDELITY_UNSPECIFIED = 0

    # Low precision. Good for covering large areas with fewer vertices.
    LOW = 1

    # Medium precision. A balance between detail and artifact size.
    MEDIUM = 2

    # High precision. High fidelity edges, but may produce holes in the polygon
    # where the road network density is low.
    HIGH = 3
  end
end

#place::String

Returns The resource name of a place, in the places/{place_id} format.

Note: The following fields are mutually exclusive: place, location. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The resource name of a place, in the places/{place_id} format.

    Note: The following fields are mutually exclusive: place, location. If a field in that set is populated, all other fields in the set will automatically be cleared.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 58

class GenerateIsochroneRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the mode of transportation for isochrone calculation.
  module TravelMode
    # No travel mode specified.
    TRAVEL_MODE_UNSPECIFIED = 0

    # Travel by passenger car.
    DRIVE = 1

    # Travel by bicycle.
    BICYCLE = 2

    # Travel by walking.
    WALK = 3
  end

  # Specifies the direction of travel for the isochrone calculation.
  module TravelDirection
    # No travel direction specified.
    TRAVEL_DIRECTION_UNSPECIFIED = 0

    # Calculates the area reachable *from* the origin point.
    # Example: "Where can I deliver to from my warehouse in 30 minutes?"
    FROM = 1

    # Calculates the area from which you can travel *to* the origin point.
    # Example: "Where can my employees commute from to reach the office in 30
    # minutes?"
    TO = 2
  end

  # Determines how traffic conditions are incorporated into the calculation.
  module RoutingPreference
    # No routing preference specified. The server will use its default,
    # which is TRAFFIC_UNAWARE.
    ROUTING_PREFERENCE_UNSPECIFIED = 0

    # The calculation will not take traffic conditions into consideration.
    # The isochrone will be based on the road network and static travel times.
    # This is suitable for planning purposes where traffic is not a factor.
    TRAFFIC_UNAWARE = 1

    # The calculation will factor in live traffic conditions.
    TRAFFIC_AWARE = 2
  end

  # Controls the level of detail in the isochrone polygon.
  module PolygonFidelity
    # No polygon fidelity specified. The server will use its default, which
    # is based on the travel duration.
    POLYGON_FIDELITY_UNSPECIFIED = 0

    # Low precision. Good for covering large areas with fewer vertices.
    LOW = 1

    # Medium precision. A balance between detail and artifact size.
    MEDIUM = 2

    # High precision. High fidelity edges, but may produce holes in the polygon
    # where the road network density is low.
    HIGH = 3
  end
end

#polygon_fidelity::Google::Maps::Isochrones::V1::GenerateIsochroneRequest::PolygonFidelity

Returns Optional. Controls the precision of the generated polygon. Defaults to POLYGON_FIDELITY_UNSPECIFIED.

Returns:



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 58

class GenerateIsochroneRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the mode of transportation for isochrone calculation.
  module TravelMode
    # No travel mode specified.
    TRAVEL_MODE_UNSPECIFIED = 0

    # Travel by passenger car.
    DRIVE = 1

    # Travel by bicycle.
    BICYCLE = 2

    # Travel by walking.
    WALK = 3
  end

  # Specifies the direction of travel for the isochrone calculation.
  module TravelDirection
    # No travel direction specified.
    TRAVEL_DIRECTION_UNSPECIFIED = 0

    # Calculates the area reachable *from* the origin point.
    # Example: "Where can I deliver to from my warehouse in 30 minutes?"
    FROM = 1

    # Calculates the area from which you can travel *to* the origin point.
    # Example: "Where can my employees commute from to reach the office in 30
    # minutes?"
    TO = 2
  end

  # Determines how traffic conditions are incorporated into the calculation.
  module RoutingPreference
    # No routing preference specified. The server will use its default,
    # which is TRAFFIC_UNAWARE.
    ROUTING_PREFERENCE_UNSPECIFIED = 0

    # The calculation will not take traffic conditions into consideration.
    # The isochrone will be based on the road network and static travel times.
    # This is suitable for planning purposes where traffic is not a factor.
    TRAFFIC_UNAWARE = 1

    # The calculation will factor in live traffic conditions.
    TRAFFIC_AWARE = 2
  end

  # Controls the level of detail in the isochrone polygon.
  module PolygonFidelity
    # No polygon fidelity specified. The server will use its default, which
    # is based on the travel duration.
    POLYGON_FIDELITY_UNSPECIFIED = 0

    # Low precision. Good for covering large areas with fewer vertices.
    LOW = 1

    # Medium precision. A balance between detail and artifact size.
    MEDIUM = 2

    # High precision. High fidelity edges, but may produce holes in the polygon
    # where the road network density is low.
    HIGH = 3
  end
end

#routing_preference::Google::Maps::Isochrones::V1::GenerateIsochroneRequest::RoutingPreference

Returns Optional. Specifies the preference for how to route. Defaults to TRAFFIC_UNAWARE.

Returns:



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 58

class GenerateIsochroneRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the mode of transportation for isochrone calculation.
  module TravelMode
    # No travel mode specified.
    TRAVEL_MODE_UNSPECIFIED = 0

    # Travel by passenger car.
    DRIVE = 1

    # Travel by bicycle.
    BICYCLE = 2

    # Travel by walking.
    WALK = 3
  end

  # Specifies the direction of travel for the isochrone calculation.
  module TravelDirection
    # No travel direction specified.
    TRAVEL_DIRECTION_UNSPECIFIED = 0

    # Calculates the area reachable *from* the origin point.
    # Example: "Where can I deliver to from my warehouse in 30 minutes?"
    FROM = 1

    # Calculates the area from which you can travel *to* the origin point.
    # Example: "Where can my employees commute from to reach the office in 30
    # minutes?"
    TO = 2
  end

  # Determines how traffic conditions are incorporated into the calculation.
  module RoutingPreference
    # No routing preference specified. The server will use its default,
    # which is TRAFFIC_UNAWARE.
    ROUTING_PREFERENCE_UNSPECIFIED = 0

    # The calculation will not take traffic conditions into consideration.
    # The isochrone will be based on the road network and static travel times.
    # This is suitable for planning purposes where traffic is not a factor.
    TRAFFIC_UNAWARE = 1

    # The calculation will factor in live traffic conditions.
    TRAFFIC_AWARE = 2
  end

  # Controls the level of detail in the isochrone polygon.
  module PolygonFidelity
    # No polygon fidelity specified. The server will use its default, which
    # is based on the travel duration.
    POLYGON_FIDELITY_UNSPECIFIED = 0

    # Low precision. Good for covering large areas with fewer vertices.
    LOW = 1

    # Medium precision. A balance between detail and artifact size.
    MEDIUM = 2

    # High precision. High fidelity edges, but may produce holes in the polygon
    # where the road network density is low.
    HIGH = 3
  end
end

#travel_direction::Google::Maps::Isochrones::V1::GenerateIsochroneRequest::TravelDirection

Returns Required. The direction of travel.

Returns:



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 58

class GenerateIsochroneRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the mode of transportation for isochrone calculation.
  module TravelMode
    # No travel mode specified.
    TRAVEL_MODE_UNSPECIFIED = 0

    # Travel by passenger car.
    DRIVE = 1

    # Travel by bicycle.
    BICYCLE = 2

    # Travel by walking.
    WALK = 3
  end

  # Specifies the direction of travel for the isochrone calculation.
  module TravelDirection
    # No travel direction specified.
    TRAVEL_DIRECTION_UNSPECIFIED = 0

    # Calculates the area reachable *from* the origin point.
    # Example: "Where can I deliver to from my warehouse in 30 minutes?"
    FROM = 1

    # Calculates the area from which you can travel *to* the origin point.
    # Example: "Where can my employees commute from to reach the office in 30
    # minutes?"
    TO = 2
  end

  # Determines how traffic conditions are incorporated into the calculation.
  module RoutingPreference
    # No routing preference specified. The server will use its default,
    # which is TRAFFIC_UNAWARE.
    ROUTING_PREFERENCE_UNSPECIFIED = 0

    # The calculation will not take traffic conditions into consideration.
    # The isochrone will be based on the road network and static travel times.
    # This is suitable for planning purposes where traffic is not a factor.
    TRAFFIC_UNAWARE = 1

    # The calculation will factor in live traffic conditions.
    TRAFFIC_AWARE = 2
  end

  # Controls the level of detail in the isochrone polygon.
  module PolygonFidelity
    # No polygon fidelity specified. The server will use its default, which
    # is based on the travel duration.
    POLYGON_FIDELITY_UNSPECIFIED = 0

    # Low precision. Good for covering large areas with fewer vertices.
    LOW = 1

    # Medium precision. A balance between detail and artifact size.
    MEDIUM = 2

    # High precision. High fidelity edges, but may produce holes in the polygon
    # where the road network density is low.
    HIGH = 3
  end
end

#travel_duration::Google::Protobuf::Duration

Returns Required. The travel time for the isochrone calculation. The value must be positive and is capped at 7200 seconds (120 minutes). For DRIVE mode, the maximum allowed duration is 3600 seconds (60 minutes).

Returns:

  • (::Google::Protobuf::Duration)

    Required. The travel time for the isochrone calculation. The value must be positive and is capped at 7200 seconds (120 minutes). For DRIVE mode, the maximum allowed duration is 3600 seconds (60 minutes).



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 58

class GenerateIsochroneRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the mode of transportation for isochrone calculation.
  module TravelMode
    # No travel mode specified.
    TRAVEL_MODE_UNSPECIFIED = 0

    # Travel by passenger car.
    DRIVE = 1

    # Travel by bicycle.
    BICYCLE = 2

    # Travel by walking.
    WALK = 3
  end

  # Specifies the direction of travel for the isochrone calculation.
  module TravelDirection
    # No travel direction specified.
    TRAVEL_DIRECTION_UNSPECIFIED = 0

    # Calculates the area reachable *from* the origin point.
    # Example: "Where can I deliver to from my warehouse in 30 minutes?"
    FROM = 1

    # Calculates the area from which you can travel *to* the origin point.
    # Example: "Where can my employees commute from to reach the office in 30
    # minutes?"
    TO = 2
  end

  # Determines how traffic conditions are incorporated into the calculation.
  module RoutingPreference
    # No routing preference specified. The server will use its default,
    # which is TRAFFIC_UNAWARE.
    ROUTING_PREFERENCE_UNSPECIFIED = 0

    # The calculation will not take traffic conditions into consideration.
    # The isochrone will be based on the road network and static travel times.
    # This is suitable for planning purposes where traffic is not a factor.
    TRAFFIC_UNAWARE = 1

    # The calculation will factor in live traffic conditions.
    TRAFFIC_AWARE = 2
  end

  # Controls the level of detail in the isochrone polygon.
  module PolygonFidelity
    # No polygon fidelity specified. The server will use its default, which
    # is based on the travel duration.
    POLYGON_FIDELITY_UNSPECIFIED = 0

    # Low precision. Good for covering large areas with fewer vertices.
    LOW = 1

    # Medium precision. A balance between detail and artifact size.
    MEDIUM = 2

    # High precision. High fidelity edges, but may produce holes in the polygon
    # where the road network density is low.
    HIGH = 3
  end
end

#travel_mode::Google::Maps::Isochrones::V1::GenerateIsochroneRequest::TravelMode

Returns Required. The mode of transportation.

Returns:



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 58

class GenerateIsochroneRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines the mode of transportation for isochrone calculation.
  module TravelMode
    # No travel mode specified.
    TRAVEL_MODE_UNSPECIFIED = 0

    # Travel by passenger car.
    DRIVE = 1

    # Travel by bicycle.
    BICYCLE = 2

    # Travel by walking.
    WALK = 3
  end

  # Specifies the direction of travel for the isochrone calculation.
  module TravelDirection
    # No travel direction specified.
    TRAVEL_DIRECTION_UNSPECIFIED = 0

    # Calculates the area reachable *from* the origin point.
    # Example: "Where can I deliver to from my warehouse in 30 minutes?"
    FROM = 1

    # Calculates the area from which you can travel *to* the origin point.
    # Example: "Where can my employees commute from to reach the office in 30
    # minutes?"
    TO = 2
  end

  # Determines how traffic conditions are incorporated into the calculation.
  module RoutingPreference
    # No routing preference specified. The server will use its default,
    # which is TRAFFIC_UNAWARE.
    ROUTING_PREFERENCE_UNSPECIFIED = 0

    # The calculation will not take traffic conditions into consideration.
    # The isochrone will be based on the road network and static travel times.
    # This is suitable for planning purposes where traffic is not a factor.
    TRAFFIC_UNAWARE = 1

    # The calculation will factor in live traffic conditions.
    TRAFFIC_AWARE = 2
  end

  # Controls the level of detail in the isochrone polygon.
  module PolygonFidelity
    # No polygon fidelity specified. The server will use its default, which
    # is based on the travel duration.
    POLYGON_FIDELITY_UNSPECIFIED = 0

    # Low precision. Good for covering large areas with fewer vertices.
    LOW = 1

    # Medium precision. A balance between detail and artifact size.
    MEDIUM = 2

    # High precision. High fidelity edges, but may produce holes in the polygon
    # where the road network density is low.
    HIGH = 3
  end
end