Module: Google::Maps::Isochrones::V1::GenerateIsochroneRequest::PolygonFidelity

Defined in:
proto_docs/google/maps/isochrones/v1/isochrones_service.rb

Overview

Controls the level of detail in the isochrone polygon.

Constant Summary collapse

POLYGON_FIDELITY_UNSPECIFIED =

No polygon fidelity specified. The server will use its default, which is based on the travel duration.

0
LOW =

Low precision. Good for covering large areas with fewer vertices.

1
MEDIUM =

Medium precision. A balance between detail and artifact size.

2
HIGH =

High precision. High fidelity edges, but may produce holes in the polygon where the road network density is low.

3