Module: Google::Maps::Isochrones::V1::GenerateIsochroneRequest::RoutingPreference

Defined in:
proto_docs/google/maps/isochrones/v1/isochrones_service.rb

Overview

Determines how traffic conditions are incorporated into the calculation.

Constant Summary collapse

ROUTING_PREFERENCE_UNSPECIFIED =

No routing preference specified. The server will use its default, which is TRAFFIC_UNAWARE.

0
TRAFFIC_UNAWARE =

The calculation will not take traffic conditions into consideration. The isochrone will be based on the road network and static travel times. This is suitable for planning purposes where traffic is not a factor.

1
TRAFFIC_AWARE =

The calculation will factor in live traffic conditions.

2