Module: Google::Maps::Isochrones::V1::GenerateIsochroneRequest::TravelDirection

Defined in:
proto_docs/google/maps/isochrones/v1/isochrones_service.rb

Overview

Specifies the direction of travel for the isochrone calculation.

Constant Summary collapse

TRAVEL_DIRECTION_UNSPECIFIED =

No travel direction specified.

0
FROM =

Calculates the area reachable from the origin point. Example: "Where can I deliver to from my warehouse in 30 minutes?"

1
TO =

Calculates the area from which you can travel to the origin point. Example: "Where can my employees commute from to reach the office in 30 minutes?"

2