Class: Google::Maps::Isochrones::V1::Isochrone
- Inherits:
-
Object
- Object
- Google::Maps::Isochrones::V1::Isochrone
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/maps/isochrones/v1/isochrones_service.rb
Overview
The result of an isochrone calculation, representing an area of reachability from an origin point within a specified travel time.
Instance Attribute Summary collapse
-
#geo_json ⇒ ::Google::Protobuf::Struct
readonly
Output only.
Instance Attribute Details
#geo_json ⇒ ::Google::Protobuf::Struct (readonly)
Returns Output only. The isochrone geometry in GeoJSON format, using the RFC 7946 format: https://datatracker.ietf.org/doc/html/rfc7946#section-3.1.6.
140 141 142 143 |
# File 'proto_docs/google/maps/isochrones/v1/isochrones_service.rb', line 140 class Isochrone include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |